@@ -1,7 +1,7 @@
 package MooX::Purple::G;
 
 use 5.006;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use PPR;
 use strict;
 use warnings;
@@ -170,17 +170,18 @@ __END__
 
 =head1 NAME
 
-MooX::Purple - MooX::Purple
+MooX::Purple::G - MooX::Purple::G
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
 =head1 SYNOPSIS
 
 	use MooX::Purple;
+	use MooX::Purple::G;
 
 	role Before {
 		public seven { return '7' }
